==> vplus-0.1.0-sources.jar: tech/nevets/vplus/blocks/LavaSpongeBlock.java <==
package tech.nevets.vplus.blocks;

import com.google.common.collect.Lists;
import net.fabricmc.fabric.api.object.builder.v1.block.FabricBlockSettings;
import net.minecraft.block.*;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2263;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2404;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_3486;
import net.minecraft.class_3545;
import net.minecraft.class_3610;
import net.minecraft.class_3614;
import java.util.Queue;

public class LavaSpongeBlock extends class_2248 {


    public LavaSpongeBlock() {
        super(FabricBlockSettings.method_9637(class_3614.field_15914).method_9632(0.6F).method_9626(class_2498.field_22143));
    }

    public void method_9615(class_2680 state, class_1937 , class_2338 , class_2680 , boolean ) {
        if (!.method_27852(state.method_26204())) {
            this.update(, );
        }
    }

    public void method_9612(class_2680 state, class_1937 , class_2338 , class_2248 , class_2338 , boolean ) {
        this.update(, );
        super.method_9612(state, , , , , );
    }

    protected void update(class_1937 world, class_2338 pos) {
        if (this.absorbLava(world, pos)) {
            world.method_8652(pos, VPBlocks.SATURATEDLAVASPONGEBLOCK.method_9564(), 2);
            world.method_20290(2001, pos, class_2248.method_9507(class_2246.field_10164.method_9564()));
        }

    }

    private boolean absorbLava(class_1937 world, class_2338 pos) {
        Queue<class_3545<class_2338, Integer>> queue = Lists.newLinkedList();
        queue.add(new class_3545(pos, 0));
        int i = 0;

        while(!queue.isEmpty()) {
            class_3545<class_2338, Integer> pair = (class_3545)queue.poll();
            class_2338 blockPos = (class_2338)pair.method_15442();
            int j = (Integer)pair.method_15441();
            class_2350[] var8 = class_2350.values();
            int var9 = var8.length;

            for(int var10 = 0; var10 < var9; ++var10) {
                class_2350 direction = var8[var10];
                class_2338 blockPos2 = blockPos.method_10093(direction);
                class_2680 blockState = world.method_8320(blockPos2);
                class_3610 fluidState = world.method_8316(blockPos2);
                class_3614 material = blockState.method_26207();
                if (fluidState.method_15767(class_3486.field_15518)) {
                    if (blockState.method_26204() instanceof class_2263 && !((class_2263)blockState.method_26204()).method_9700(world, blockPos2, blockState).method_7960()) {
                        ++i;
                        if (j < 6) {
                            queue.add(new class_3545(blockPos2, j + 1));
                        }
                    } else if (blockState.method_26204() instanceof class_2404) {
                        world.method_8652(blockPos2, class_2246.field_10124.method_9564(), 3);
                        ++i;
                        if (j < 6) {
                            queue.add(new class_3545(blockPos2, j + 1));
                        }
                    }
                }
            }
            if (i > 64) {
                break;
            }
        }
        return i > 0;
    }
}

==> vplus-1.1.1-sources.jar: tech/nevets/vplus/blocks/LavaSpongeBlock.java <==
package tech.nevets.vplus.blocks;

import com.google.common.collect.Lists;
import net.fabricmc.fabric.api.object.builder.v1.block.FabricBlockSettings;
import net.minecraft.block.*;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2263;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2404;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_3486;
import net.minecraft.class_3545;
import net.minecraft.class_3610;
import net.minecraft.class_3614;
import java.util.Queue;

public class LavaSpongeBlock extends class_2248 {


    public LavaSpongeBlock() {
        super(FabricBlockSettings.method_9637(class_3614.field_15914).method_9632(0.6F).method_9626(class_2498.field_22143));
    }

    public void method_9615(class_2680 state, class_1937 world, class_2338 pos, class_2680 oldState, boolean notify) {
        if (!oldState.method_27852(state.method_26204())) {
            this.update(world, pos);
        }
    }

    public void method_9612(class_2680 state, class_1937 world, class_2338 pos, class_2248 block, class_2338 fromPos, boolean notify) {
        this.update(world, pos);
        super.method_9612(state, world, pos, block, fromPos, notify);
    }

    protected void update(class_1937 world, class_2338 pos) {
        if (this.absorbLava(world, pos)) {
            world.method_8652(pos, VPBlocks.SATURATEDLAVASPONGEBLOCK.method_9564(), 2);
            world.method_20290(2001, pos, class_2248.method_9507(class_2246.field_10164.method_9564()));
        }

    }

    private boolean absorbLava(class_1937 world, class_2338 pos) {
        Queue<class_3545<class_2338, Integer>> queue = Lists.newLinkedList();
        queue.add(new class_3545(pos, 0));
        int i = 0;

        while(!queue.isEmpty()) {
            class_3545<class_2338, Integer> pair = (class_3545)queue.poll();
            class_2338 blockPos = (class_2338)pair.method_15442();
            int j = (Integer)pair.method_15441();
            class_2350[] var8 = class_2350.values();
            int var9 = var8.length;

            for(int var10 = 0; var10 < var9; ++var10) {
                class_2350 direction = var8[var10];
                class_2338 blockPos2 = blockPos.method_10093(direction);
                class_2680 blockState = world.method_8320(blockPos2);
                class_3610 fluidState = world.method_8316(blockPos2);
                class_3614 material = blockState.method_26207();
                if (fluidState.method_15767(class_3486.field_15518)) {
                    if (blockState.method_26204() instanceof class_2263 && !((class_2263)blockState.method_26204()).method_9700(world, blockPos2, blockState).method_7960()) {
                        ++i;
                        if (j < 6) {
                            queue.add(new class_3545(blockPos2, j + 1));
                        }
                    } else if (blockState.method_26204() instanceof class_2404) {
                        world.method_8652(blockPos2, class_2246.field_10124.method_9564(), 3);
                        ++i;
                        if (j < 6) {
                            queue.add(new class_3545(blockPos2, j + 1));
                        }
                    }
                }
            }
            if (i > 64) {
                break;
            }
        }
        return i > 0;
    }
}
